@@ -1,22 +1,9 @@
-/*  This file is part of the KDE libraries
- *  Copyright 2016 Aleix Pol Gonzalez <aleixpol@kde.org>
- *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License or ( at
- *  your option ) version 3 or, at the discretion of KDE e.V. ( which shall
- *  act as a proxy as in section 14 of the GPLv3 ), any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2016 Aleix Pol Gonzalez <aleixpol@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #include <QCoreApplication>
 #include <QUrl>
@@ -33,9 +20,13 @@
 #include <KNSCore/Engine>
 #include <KNSCore/QuestionManager>
 
+#include "knshandlerversion.h"
+
 int main(int argc, char** argv)
 {
     QCoreApplication app(argc, argv);
+    app.setApplicationName(QLatin1String("kpackage-knshandler"));
+    app.setApplicationVersion(knshandlerversion);
     app.setQuitLockEnabled(false);
     Q_ASSERT(app.arguments().count() == 2);
 
@@ -61,7 +52,11 @@ int main(int argc, char** argv)
         return 1;
     }
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const auto pathParts = url.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
+#else
+    const auto pathParts = url.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
+#endif
     if (pathParts.size() != 2) {
         qWarning() << "wrong format in the url path" << url << pathParts;
         return 1;
@@ -113,8 +108,8 @@ int main(int argc, char** argv)
         engine.fetchEntryById(entryid);
     });
 
-    QObject::connect(&engine, &KNSCore::Engine::signalError, &engine, [](const QString &error) {
-        qWarning() << "kns error:" << error;
+    QObject::connect(&engine, &KNSCore::Engine::signalErrorCode, &engine, [](const KNSCore::ErrorCode &errorCode, const QString &message, const QVariant &metadata) {
+        qWarning() << "kns error:" << errorCode << message << metadata;
         QCoreApplication::exit(1);
     });
     QObject::connect(&engine, &KNSCore::Engine::signalEntryDetailsLoaded, &engine, [providerid, linkid, &engine, &installedCount](const KNSCore::EntryInternal &entry) {
